@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2008 Sun Microsystems Inc.
+# Copyright 2004-2009 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -22,7 +22,7 @@
 __id__  = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
-__copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
+__copyright__ = "Copyright (c) 2005-2009 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import gobject
@@ -147,7 +147,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         - script: the script.
         """
 
-        if settings.listenAllEvents: 
+        if settings.listenAllEvents:
             # We are always listening to everything.
             return
 
@@ -161,7 +161,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         Arguments:
         - script: the script.
         """
-        if settings.listenAllEvents: 
+        if settings.listenAllEvents:
             # We are always listening to everything.
             return
 
@@ -497,27 +497,24 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         #
         try:
             if event.source.getRole() == pyatspi.ROLE_TOOL_TIP:
-                # Check that it's okay to present tool tips. Always present
-                # tooltips initiated by the user pressing Control-F1 on the
-                # keyboard.
-                #
-                if isinstance(orca_state.lastInputEvent, \
-                              input_event.KeyboardEvent):
-                    if not orca_state.lastNonModifierKeyEvent.event_string \
-                                                                     == "F1":
-                        return
-
-                    # Mouse move events don't update orca_state.lastInputEvent
-                    # so it's possible the user accidentally nudged the
-                    # mouse and generated another tooltip event. If the
-                    # current time minus the last keyboard event time is
-                    # greater than 0.2 seconds, than just ignore this tooltip
-                    # event.
+                if settings.presentToolTips:
+                    pass
+                elif isinstance(orca_state.lastInputEvent, \
+                                input_event.KeyboardEvent) \
+                     and orca_state.lastNonModifierKeyEvent.event_string \
+                         == "F1":
+                    # Always present tooltips initiated by the user
+                    # pressing Control-F1 on the keyboard.  Mouse move
+                    # events don't update orca_state.lastInputEvents,
+                    # however, so it's possible the user accidentally
+                    # nudged the mouse after pressing F1 and generated
+                    # another tooltip event. If the current time minus
+                    # the last keyboard event time is greater than 0.5
+                    # seconds, than just ignore this tooltip event.
                     #
-                    currentTime =  time.time()
-                    if (currentTime - orca_state.lastInputEvent.time) > 0.2:
+                    if (time.time() - orca_state.lastInputEvent.time) > 0.5:
                         return
-                elif not settings.presentToolTips:
+                else:
                     return
         except:
             pass
@@ -670,6 +667,17 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                                 and (orca_state.activeScript.app \
                                      != event.host_application)
 
+                    # One last check -- let's make sure the new script
+                    # thinks it should become active.
+                    #
+                    if setNewActiveScript:
+                        theScript = \
+                            self.getScript(event.host_application \
+                                           or event.source.getApplication())
+                        setNewActiveScript = theScript.isActivatableEvent(event)
+                        if not reason and setNewActiveScript:
+                            reason = "script requested it"
+
                     if not reason and setNewActiveScript:
                         reason = "object received focus"
 
@@ -788,7 +796,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
             # If the event doesn't have a source or that source is not marked
             # valid, then we don't care about this event. Just return.
             #
-            
+
             event = e
             if not event.source:
                 debug.println(debug.LEVEL_FINEST,
